==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/igc-format-specifier-collection.js <==
import * as tslib_1 from "tslib";
import { IgCollection } from './IgCollection';
import { markType } from './type';
import { SyncableObservableCollection$2 } from './SyncableObservableCollection$2';
import { FormatSpecifier as FormatSpecifier_internal } from './FormatSpecifier';
import { IgcFormatSpecifier as IgcFormatSpecifier } from './igc-format-specifier';
var IgcFormatSpecifierCollection = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(IgcFormatSpecifierCollection, _super);
    function IgcFormatSpecifierCollection(list) {
        var _this = _super.call(this) || this;
        if (!IgcFormatSpecifier.$type) {
            IgcFormatSpecifier.$type = markType(IgcFormatSpecifier, "IgcFormatSpecifier");
        }
        if (list) {
            for (var i = 0; i < list.length; i++) {
                _this.add(list[i]);
            }
        }
        return _this;
    }
    IgcFormatSpecifierCollection.prototype._createInnerColl = function () {
        if (!IgcFormatSpecifier.$type) {
            IgcFormatSpecifier.$type = markType(IgcFormatSpecifier, "IgcFormatSpecifier");
        }
        var coll = new SyncableObservableCollection$2(IgcFormatSpecifier.$type, FormatSpecifier_internal.$type, 0);
        coll.compare = function (ext, int) {
            var comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = function (ext) {
            return ext._implementation;
        };
        coll.createFrom = function (int) {
            var ext = int.externalObject;
            if (!ext) {
                ext = new IgcFormatSpecifier();
                if (ext) {
                    ext._implementation = int;
                }
            }
            return ext;
        };
        return coll;
    };
    return IgcFormatSpecifierCollection;
}(IgCollection));
export { IgcFormatSpecifierCollection };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/igc-format-specifier-collection.js <==
import { __extends } from "tslib";
import { IgCollection } from './IgCollection';
import { markType } from './type';
import { SyncableObservableCollection$2 } from './SyncableObservableCollection$2';
import { FormatSpecifier as FormatSpecifier_internal } from './FormatSpecifier';
import { IgcFormatSpecifier as IgcFormatSpecifier } from './igc-format-specifier';
var IgcFormatSpecifierCollection = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcFormatSpecifierCollection, _super);
    function IgcFormatSpecifierCollection(list) {
        var _this = _super.call(this) || this;
        if (!IgcFormatSpecifier.$type) {
            IgcFormatSpecifier.$type = markType(IgcFormatSpecifier, "IgcFormatSpecifier");
        }
        if (list) {
            for (var i = 0; i < list.length; i++) {
                _this.add(list[i]);
            }
        }
        return _this;
    }
    IgcFormatSpecifierCollection.prototype._createInnerColl = function () {
        if (!IgcFormatSpecifier.$type) {
            IgcFormatSpecifier.$type = markType(IgcFormatSpecifier, "IgcFormatSpecifier");
        }
        var coll = new SyncableObservableCollection$2(IgcFormatSpecifier.$type, FormatSpecifier_internal.$type, 0);
        coll.compare = function (ext, int) {
            var comp = ext;
            if (comp._implementation) {
                comp = comp._implementation;
            }
            if (comp.equals) {
                return comp.equals(int);
            }
            return comp === int;
        };
        coll.createTo = function (ext) {
            return ext._implementation;
        };
        coll.createFrom = function (int) {
            var ext = int.externalObject;
            if (!ext) {
                ext = new IgcFormatSpecifier();
                if (ext) {
                    if (!int.$type && ext._implementation.setNativeElement) {
                        ext._implementation.setNativeElement(int);
                    }
                    else {
                        ext._implementation = int;
                    }
                }
            }
            return ext;
        };
        return coll;
    };
    return IgcFormatSpecifierCollection;
}(IgCollection));
export { IgcFormatSpecifierCollection };
